#!/usr/bin/perl -w
use strict;

# Fetch some information from a LabKey server using the client API
my $email = 'user@labkey.com';
my $password = 'mypassword';

use LWP::UserAgent;
use HTTP::Request;
my $ua = new LWP::UserAgent;
$ua->agent("Perl API Client/1.0");

# Setup variables
# schemaName should be the name of a valid schema. The "lists" schema contains all lists created via the List module
# queryName should be the name of a valid query within that schema. For a list, the query name is the name of the list
# project should be the folder path in which the data resides. Use a forward slash to separate the path
# host should be the domain name of your LabKey server
# labkeyRoot should be the root of the LabKey web site (if LabKey is installed on the root of the site, omit this from the url)
my $schemaName="lists";
my $queryName="MyList";
my $project="MyProject/MyFolder/MySubFolder";
my $host="localhost:8080";
my $labkeyRoot = "labkey";
my $protocol="http";

#build the url to call the selectRows.api
#for other APIs, see the example URLs in the Server-Side APIs documentation at
#https://www.labkey.org/wiki/home/Documentation/page.view?name=remoteAPIs
my $url = "$protocol://$host/$labkeyRoot/query/$project/" .
  "selectRows.api?schemaName=$schemaName&query.queryName=$queryName";

#Fetch the actual data from the query
my $request = HTTP::Request->new("GET" => $url);
$request->authorization_basic($email, $password);
my $response = $ua->request($request);

# use JSON 2.07 to decode the response: This can be downloaded from 
# http://search.cpan.org/~makamaka/JSON-2.07/
use JSON;
my $json_obj = JSON->new->utf8->decode($response->content);

# the number of rows returned will be in the 'rowCount' propery
print $json_obj->{rowCount} . " rows:\n";

# and the rows array will be in the 'rows' property.
foreach my $row(@{$json_obj->{rows}}){
	#Results from this particular query have a "Key" and a "Value"
	print $row->{Key} . ":" . $row->{Value} . "\n";
}
